
// $Id: AlienCommandDialog.cpp,v 1.18 2014/09/26 08:06:18 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/


#include "AlienCommandDialog.h"
#include "AlienCommandDialog.moc"

#include "AlienCommandModel.h"
#include "AlienMacroModel.h"
#include "ColumnSelectionMenu.h"
#include "ColumnSortingMenu.h"
#include "ContextMenu.h"
#include "IconSize.h"
#include "TreeView.h"

#include <QGroupBox>
#include <QHeaderView>
#include <QShortcut>
#include <QSplitter>

//__________________________________________________
AlienCommandDialog::AlienCommandDialog( QWidget* parent ):
    CustomDialog( parent, CloseButton ),
    macroModel_( 0 ),
    commandModel_( 0 )
{

    Debug::Throw( "AlienCommandDialog::AlienCommandDialog.\n" );
    setWindowTitle( tr( "Command List - Gridwatch" ) );
    setOptionName( "ALIEN_COMMAND_DIALOG" );

    // customize layout
    layout()->setMargin(0);
    layout()->setSpacing(0);
    buttonLayout().setMargin(5);

    QSplitter* splitter;
    mainLayout().addWidget( splitter = new QSplitter( this ) );
    splitter->setOrientation( Qt::Vertical );

    // macros
    {

        QWidget* container = new QGroupBox( tr( "Macros" ) );
        splitter->addWidget( container );

        container->setLayout( new QVBoxLayout() );
        container->layout()->addWidget( macroList_ = new TreeView(container) );

        macroList_->header()->hide();
        macroList_->setSortingEnabled( true );
        macroList_->setIconSize( IconSize( IconSize::Medium ) );
        macroList_->setSelectionMode( TreeView::ContiguousSelection );
        macroList_->setModel( &macroModel_ );
        macroList_->setOptionName( "ALIEN_MACRO_LIST" );

        QMenu* menu( new ContextMenu( macroList_ ) );
        menu->addMenu( new ColumnSortingMenu( menu, macroList_ ) );
        menu->addMenu( new ColumnSelectionMenu( menu, macroList_ ) );

    }

    // commands
    {
        QWidget* container = new QGroupBox( tr( "Commands" ) );
        splitter->addWidget( container );

        container->setLayout( new QVBoxLayout() );
        container->layout()->addWidget( commandList_ = new TreeView(container) );

        commandList_->header()->hide();
        commandList_->setSortingEnabled( true );
        commandList_->setIconSize( IconSize( IconSize::Medium ) );
        commandList_->setSelectionMode( TreeView::ContiguousSelection );
        commandList_->setModel( &commandModel_ );
        commandList_->setOptionName( "ALIEN_COMMAND_LIST" );

        QMenu* menu( new ContextMenu( commandList_ ) );
        menu->addMenu( new ColumnSortingMenu( menu, commandList_ ) );
        menu->addMenu( new ColumnSelectionMenu( menu, commandList_ ) );

    }

    // ok button
    connect( &okButton(), SIGNAL(pressed()), SLOT(close()) );

    // close accelerator
    new QShortcut( QKeySequence::Close, this, SLOT(close()) );

}

//_____________________________________________________________
void AlienCommandDialog::closeEvent( QCloseEvent* event )
{
    Debug::Throw( "AlienCommandDialog::closeEvent.\n" );
    emit dialogHidden();
    return CustomDialog::closeEvent( event );
}
