
// $Id: AlienMacro.cpp,v 1.15 2013/04/29 18:27:12 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AlienMacro.h"
#include "FileInfo.h"

//___________________________________________________________________
unsigned int& AlienMacro::_counter( void )
{
    static unsigned int counter( 0 );
    return counter;
}

//___________________________________________________________________
AlienMacro::AlienMacro( Type type, Flags flags ):
    Counter( "AlienMacro" ),
    id_( _counter()++ ),
    type_( type ),
    flags_( flags )
{}

//___________________________________________________________________
QString AlienMacro::name( const Type& type )
{
    if( _names().empty() ) _initializeNames();
    return _names()[ type ];
}

//___________________________________________________________________
AlienMacro::NameMap& AlienMacro::_names( void )
{
    static NameMap names;
    return names;
}

//___________________________________________________________________
void AlienMacro::_initializeNames( void )
{
    _names()[None] = QObject::tr( "none" );
    _names()[Add] = QObject::tr( "add file to internal list" );
    _names()[Clear] = QObject::tr( "clear internal file list" );
    _names()[FlushErrors] = QObject::tr( "check failed commands" );
    _names()[Connect] = QObject::tr( "connect" );
    _names()[CheckProxy] = QObject::tr( "check GSI proxy validity" );
    _names()[HomeDirectory] = QObject::tr( "query home directory" );
    _names()[ShowDirectory] = QObject::tr( "query directory content" );
    _names()[CreateDirectory] = QObject::tr( "create directory" );
    _names()[Copy] = QObject::tr( "copy selected items" );
    _names()[Locate] = QObject::tr( "locate selected items" );
    _names()[Rename] = QObject::tr( "rename selected item" );
    _names()[Remove] = QObject::tr( "remove selected items" );
    _names()[Open] = QObject::tr( "open selected items" );
    _names()[Find] = QObject::tr( "find files collection" );
    _names()[ListRecursive] = QObject::tr( "query directory content (recursive)" );
    _names()[SizeRecursive] = QObject::tr( "query directory size (recursive)" );
    _names()[CopyRecursive] = QObject::tr( "copy selected items (recursive)" );
    _names()[RemoveRecursive] = QObject::tr( "remove selected items (recursive)" );
    _names()[CheckFilesExist] = QObject::tr( "check file existence" );
    _names()[ClearSelection] = QObject::tr( "clear display selection" );
    _names()[Select] = QObject::tr( "update display selection" );
}
