#ifndef Application_h
#define Application_h

// $Id: Application.h,v 1.24 2014/02/26 10:36:41 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "BaseApplication.h"
#include "CommandLineArguments.h"
#include "Config.h"
#include "Counter.h"
#include "FileInfo.h"
#include "PixmapEngine.h"

class MainWindow;
class ScratchFileMonitor;

//! Main Window singleton object
class Application: public BaseApplication, public Counter
{

    //! Qt meta object declaration
    Q_OBJECT

    public:

    //! constructor
    Application( CommandLineArguments );

    //! destructor
    ~Application( void );

    //! create all widgets
    bool realizeWidget( void );

    //! cvs log frame
    MainWindow & mainWindow( void ) const
    { return *mainWindow_; }

    //! scratch files
    ScratchFileMonitor& scratchFileMonitor( void ) const
    { return *scratchFileMonitor_; }

    //!@name application information
    //@{

    //! command line parser
    CommandLineParser commandLineParser( CommandLineArguments = CommandLineArguments(), bool ignoreWarnings = true ) const;

    //! usage
    void usage( void ) const;

    //! application name
    virtual QString applicationName( void ) const
    { return "Gridftp"; }

    //! application icon
    virtual QIcon applicationIcon( void ) const
    {
        QIcon icon;
        icon.addPixmap( PixmapEngine::get( ":/gridftp.png" ) );
        icon.addPixmap( PixmapEngine::get( ":/gridftp-large.png" ) );
        return icon;
    }

    // application version
    virtual QString applicationVersion( void ) const
    { return VERSION; }

    // build time stamp
    virtual QString buildTimeStamp( void ) const
    { return BUILD_TIMESTAMP; }

    //@}

    protected Q_SLOTS:

    //! configuration
    void _configuration( void );

    //! process request from application manager
    virtual bool _processCommand( Server::ServerCommand );

    private:

    //! cvs log display frame
    MainWindow *mainWindow_;

    //! scratch files
    ScratchFileMonitor* scratchFileMonitor_;

};

#endif
