/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "CopyFilesDialog.h"
#include "CopyFilesDialog.moc"

#include "BaseIconNames.h"
#include "IconEngine.h"
#include "TreeView.h"
#include "XmlOptions.h"

#include <QHeaderView>
#include <QLabel>
#include <QLayout>
#include <QScrollBar>

//____________________________________________________________________________
CopyFilesDialog::CopyFilesDialog( QWidget* parent, const FileInfo::List& files, const File& destination ):
    QuestionDialog( parent ),
    model_( this )
{

    Debug::Throw( "CopyFilesDialog::CopyFilesDialog.\n" );

    // option name
    setOptionName( "COPY_FILES_DIALOG" );

    // customize buttons
    okButton().setText( tr( "Copy" ) );
    okButton().setIcon( IconEngine::get( IconNames::Copy ) );

    // label
    setText( QString( tr( "Copy %1 to folder %2" ) )
        .arg( files.description( FileInfo::List::LowerCase ) )
        .arg( destination ) );

    TreeView* treeView( new TreeView( this ) );
    treeView->setSelectionMode( QAbstractItemView::NoSelection );

    model_.setShowIcons( false );
    model_.add( files );
    model_.sort( FileInfoModel::Filename, Qt::DescendingOrder );

    // setup list
    treeView->setModel( &model_ );
    treeView->toggleShowHeader( false );
    treeView->setMask( 1<<FileInfoModel::Filename );
    treeView->header()->setSortIndicator( FileInfoModel::Filename, Qt::AscendingOrder );

    // resize list to accomodate longest item
    int maxWidth( 0 );
    foreach( const FileInfo& fileInfo, files )
    { maxWidth = qMax( maxWidth, treeView->fontMetrics().width( fileInfo.file() ) ); }

    treeView->verticalScrollBar()->adjustSize();
    treeView->setMinimumSize( QSize(
        maxWidth + treeView->verticalScrollBar()->width() + 10,
        treeView->fontMetrics().height() + 10 ) );

    setDetails( treeView );

}
