#ifndef DefaultOptions_h
#define DefaultOptions_h

// $Id: DefaultOptions.h,v 1.30 2014/04/11 08:48:07 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AlienCommandModel.h"
#include "AlienMacroModel.h"
#include "FileInfoModel.h"
#include "FileSelectionFrame.h"
#include "Util.h"
#include "XmlOptions.h"

//_____________________________________________________
//! default options installer
void installDefaultOptions( void )
{

    // set options default values
    XmlOptions::get().setAutoDefault( true );
    XmlOptions::get().keep( "APPLICATIONS" );
    XmlOptions::get().keep( "COLLECTION_SEARCH_STRING" );

    // customize pixmap paths
    XmlOptions::get().keep( "PIXMAP_PATH" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/128x128" );
    XmlOptions::get().add( "PIXMAP_PATH", ":/pixmaps/48x48" );

    XmlOptions::get().set<int>( "DB_SIZE", 30 );
    XmlOptions::get().set<int>( "MAIN_WINDOW_HEIGHT", 500 );
    XmlOptions::get().set<int>( "MAIN_WINDOW_WIDTH", 700 );

    XmlOptions::get().set<bool>( "LOG_ENABLED", true );
    XmlOptions::get().set<bool>( "SHOW_COMMAND_LIST", false );
    XmlOptions::get().set<bool>( "SHOW_LOG", false );
    XmlOptions::get().set<bool>( "SHOW_HIDDEN_FILES", false );
    XmlOptions::get().set<bool>( "SHOW_TOOLTIPS", false );
    XmlOptions::get().set<bool>( "RESTORE_SESSION", true );

    XmlOptions::get().set<bool>( "USE_PREFIX", true );
    XmlOptions::get().set<bool>( "USE_TRUNCATION", true );
    XmlOptions::get().set<bool>( "SHOW_NAVIGATOR", true );

    // Alien connection
    XmlOptions::get().set( "ALIEN_HOST", "pcapiserv03.cern.ch" );
    XmlOptions::get().set<int>( "ALIEN_PORT", 10000 );

    // view mode
    XmlOptions::get().set<int>( "LOCAL_VIEW_MODE", FileSelectionFrame::Icons );
    XmlOptions::get().set<int>( "REMOTE_VIEW_MODE", FileSelectionFrame::Icons );

    // list mask
    XmlOptions::get().set<int>( "LOCAL_LIST_MASK", (1<<FileInfoModel::Filename) | (1<<FileInfoModel::Size) );
    XmlOptions::get().set<int>( "REMOTE_LIST_MASK", (1<<FileInfoModel::Filename) | (1<<FileInfoModel::Size) );
    XmlOptions::get().set<int>( "LOCAL_LIST_SORT_ORDER", 0 );
    XmlOptions::get().set<int>( "REMOTE_LIST_SORT_ORDER", 0 );

    // certificates path
    XmlOptions::get().set( "CERTIFICATES_PATH", Util::env( "XrdSecSSLCADIR" ) );

    // command list
    XmlOptions::get().set<int>( "ALIEN_COMMAND_LIST_MASK", 1<<AlienCommandModel::Name );
    XmlOptions::get().set<int>( "ALIEN_MACRO_LIST_MASK", 1<<AlienMacroModel::Name );

    // pixmap size
    XmlOptions::get().set<int>( "ICON_VIEW_PIXMAP_SIZE", 48 );

    // history
    XmlOptions::get().set<bool>( "SAVE_HISTORY", false );
    XmlOptions::get().set<int>( "HISTORY_SIZE", 10 );

    // database file
    XmlOptions::get().set( "HELP_FILE", File( "/.gridftp_help" ).addPath( Util::home() ) );
    XmlOptions::get().set( "RC_FILE", File(".gridftprc").addPath( Util::home() ) );
    XmlOptions::get().setAutoDefault( false );

};

#endif
