#ifndef FindCollectionDialog_h
#define FindCollectionDialog_h

// $Id: FindCollectionDialog.h,v 1.10 2014/07/25 08:30:43 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "AlienMacro.h"
#include "CustomDialog.h"
#include "ElidedLabel.h"
#include "File.h"

#include <QComboBox>
#include <QLabel>
#include <QPushButton>

class CustomComboBox;
class TextEditor;

//! QDialog used to commit selected files
class FindCollectionDialog: public CustomDialog
{

    Q_OBJECT

    public:

    //! constructor
    FindCollectionDialog( QWidget* = 0 );

    //! destructor
    virtual ~FindCollectionDialog( void )
    {}

    //! set path
    void setPath( const File& value )
    {
        path_ = value;
        pathLabel_->setText( value );
    }

    //! pattern
    void setPattern( const QString& );

    //! set default filename
    void setDefaultFilename( const File& value )
    { filename_ = value; }

    Q_SIGNALS:

    //! request command
    void macroRequested( const AlienMacro& );

    public Q_SLOTS:

    //! process collection
    void processCollection( const QString& );

    protected Q_SLOTS:

    //! clear history
    void _clearHistory( void );

    //! request collection update
    void _requestUpdate( void );

    //! save collection
    void _save( void );

    //! update buttons
    void _updateButtons( void );

    private:

    //! path
    File path_;

    //! file name
    File filename_;

    //! path
    ElidedLabel* pathLabel_;

    //! pattern editor
    CustomComboBox* patternComboBox_;

    //! collection type (flat | Xml)
    QComboBox* comboBox_;

    //! collection editor
    TextEditor* editor_;

    //! update button
    QPushButton* findButton_;

    //! save button
    QPushButton* saveButton_;

    //! status label
    QLabel* statusLabel_;

};

#endif
