// $Id: Menu.cpp,v 1.24 2014/02/03 10:08:24 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Menu.h"
#include "Menu.moc"

#include "Debug.h"
#include "DebugMenu.h"
#include "DockWidget.h"
#include "Application.h"
#include "FileSelectionFrame.h"
#include "MainWindow.h"
#include "Singleton.h"
#include "ViewModeMenu.h"
#include "XmlOptions.h"

#include <QMenu>

//__________________________________________________
Menu::Menu( QWidget* parent ):
    QMenuBar( parent ),
    Counter( "Menu" )
{

    Debug::Throw( "Menu::Menu\n" );

    // generic menu
    QMenu *menu;

    // application and top widget
    Application& application( *static_cast<Application*>(Singleton::get().application()) );
    MainWindow& mainWindow( *static_cast<MainWindow*>( window() ) );

    // file menu
    menu = addMenu( tr( "File" ) );
    menu->addAction( &mainWindow.connectAction() );
    menu->addAction( &application.closeAction() );

    menu = addMenu( tr( "View" ) );
    menu->addMenu( viewModeMenu_ = new ViewModeMenu( this ) );
    viewModeMenu_->setTitle( tr( "View Mode" ) );
    menu->addSeparator();
    menu->addAction( &mainWindow.showHiddenFilesAction() );
    menu->addAction( &mainWindow.localSelectionFrame().visibilityAction() );
    menu->addAction( &mainWindow.placesPanel().visibilityAction() );
    menu->addSeparator();
    menu->addAction( &mainWindow.logAction() );
    menu->addAction( &mainWindow.commandDialogAction() );

    // Settings menu
    menu = addMenu( tr( "Settings" ) );
    menu->addAction( &mainWindow.toggleLogAction() );
    menu->addSeparator();
    menu->addAction( &application.configurationAction() );

    // create help menu
    menu = addMenu( tr( "Help" ) );
    menu->addAction( &application.aboutAction() );
    menu->addAction( &application.aboutQtAction() );

    // debug menu
    menu->addSeparator();
    DebugMenu *debugMenu( new DebugMenu( menu ) );
    menu->addAction( debugMenu->menuAction() );
    debugMenu->menuAction()->setVisible( false );

}
